# Generated by Django 4.1.9 on 2023-05-10 11:39

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("onetimelink", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="download",
            name="down_file",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="downloads",
                to="onetimelink.uploadfile",
            ),
        ),
        migrations.AlterField(
            model_name="uploadfile",
            name="file",
            field=models.FileField(
                blank=True,
                help_text="Select the file to upload",
                max_length=255,
                null=True,
                upload_to="",
                verbose_name="file",
            ),
        ),
    ]



from django.conf import settings
from django.utils.translation import gettext_lazy as _

KEY_POLL = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz1234567890'
KEY_LENGTH = 31

# A path to a directory from witch walk down so you can choose your files.
DYNAMIC_LINK_MEDIA = getattr(
    settings,
    'DYNAMIC_LINK_MEDIA',
    settings.MEDIA_ROOT
)

# A string that modify the serve url path:
# www.example.com/DYNAMIC_LINK_URL_BASE_COMPONENT/link/3839hd8HKl3/example.zip
DYNAMIC_LINK_URL_BASE_COMPONENT = getattr(
    settings,
    'DYNAMIC_LINK_URL_BASE_COMPONENT',
    'OneTimeLink'
)

# Prefixes if FORCE_SCRIPT_NAME
DYNAMIC_LINK_URL = ''
DYNAMIC_LINK_USE_FORCE_SCRIPT_NAME = getattr(
    settings,
    'DYNAMIC_LINK_USE_FORCE_SCRIPT_NAME',
    False
)
if DYNAMIC_LINK_USE_FORCE_SCRIPT_NAME and settings.FORCE_SCRIPT_NAME:
    DYNAMIC_LINK_URL = settings.FORCE_SCRIPT_NAME + '/' + DYNAMIC_LINK_URL_BASE_COMPONENT
else:
    DYNAMIC_LINK_URL = '/' + DYNAMIC_LINK_URL_BASE_COMPONENT
DYNAMIC_LINK_URL = DYNAMIC_LINK_URL.replace('//', '/')

# Uploaded files base directory
DYNAMIC_LINK_UPLOAD_TO = getattr(
    settings,
    'DYNAMIC_LINK_UPLOAD_TO',
    ''
)

# Setting for schema protocol
DYNAMIC_LINK_SCHEMA_PROTO = getattr(
    settings,
    'DYNAMIC_LINK_SCHEMA_PROTO',
    'http'
)

# Setting for HTTP Host override
DYNAMIC_LINK_HTTP_HOST = getattr(
    settings,
    'DYNAMIC_LINK_HTTP_HOST',
    None
)

# It's here because of not violate the DRY priciple.
TEXT_REQUEST_DOES_NOT_EXIST = _(u'This request does not exist.')
TEXT_REQUEST_IS_EXPIRED = _(u'Sorry, this request is already expired')



from django.contrib import admin
from django.urls import path
from django.urls import reverse
from django.http import HttpResponseRedirect
from django.utils.translation import gettext_lazy as _
from django.utils.safestring import mark_safe
from django.utils.html import escape

from .models import DownloadSite, Download, UploadFile

from . import presettings
from . import api


@admin.register(DownloadSite)
class DownloadSiteAdmin(admin.ModelAdmin):
    change_list_template = "sitedownload_changelist.html"

    def get_queryset(self, request):
        """catch the request object for list pages"""
        self.request = request
        return super(DownloadSiteAdmin, self).get_queryset(request)

    list_display = ('pk', 'link', 'timestamp_creation')
    search_fields = ['timestamp_creation']

    def get_urls(self):
        urls = super().get_urls()
        my_urls = [
            path('downloadsite/', self.make_downloadsite)
        ]
        return my_urls + urls

    def make_downloadsite(self, request):
        download_site = DownloadSite()
        download_site.save()
        for down_file in UploadFile.objects.all():
            download = Download(site=download_site, down_file=down_file)
            download.save()
        return HttpResponseRedirect('../')

    def link(self, obj):
        """Generate download url for the site"""
        site_link = api.site_link_url(self.request, obj)
        site_link = u'<span style="color: #FF7F00; ">%s:</span> \
        <a target="new" href="%s/">%s/</a><br/>' \
            % (str(_(u'Site')), site_link, site_link)

        return mark_safe(site_link)
    link.allow_tags = True
    link.short_description = _(u'link')


@admin.register(Download)
class DownloadAdmin(admin.ModelAdmin):
    def get_queryset(self, request):
        """catch the request object for list pages"""
        self.request = request
        return super(DownloadAdmin, self).get_queryset(request)

    list_display = ('site', 'upload_file', 'file', 'active', 'link',
                    'timestamp_creation')
    search_fields = ['site__link_key', 'upload_file', 'link']
    list_per_page = 50
    fieldsets = (
        (_(u'Link'), {
            'fields': ('site', 'down_file', 'active')
        }),
    )

    def upload_file(self, obj):
        link = reverse('admin:%s_%s_change' % (obj.down_file._meta.app_label, obj.down_file._meta.model_name), args=[obj.down_file.id])
        return mark_safe(f'<a href="{link}">{escape(obj.down_file.__str__())}</a>')
    upload_file.allow_tags = True
    upload_file.short_description = _(u'upload_file')

    def file(self, obj):
        """Shows truncated filename on platform independent length."""
        return str(obj.down_file.file.path).split(presettings.DYNAMIC_LINK_MEDIA)[-1]
    file.allow_tags = True
    file.short_description = _(u'file')

    def link(self, obj):
        """Generate download url from link object"""
        file_link = api.file_link_url(self.request, obj)
        file_link = u'<span style="color: #FF7F00; ">%s:</span> \
        <a target="new" href="%s/">%s/</a><br/>' \
            % (str(_(u'File')), file_link, file_link)
        return mark_safe(file_link)
    link.allow_tags = True
    link.short_description = _(u'link')


@admin.register(UploadFile)
class UploadFileAdmin(admin.ModelAdmin):
    list_display = [
        'display_name',
        'file',
    ]
    fieldsets = (
        (_(u'Upload Files'), {
            'fields': ('file', 'display_name')
        }),
    )



#!/usr/bin/python
# -*- coding:utf-8 -*-
# This Python file uses the following encoding: utf-8
from setuptools import setup, find_packages
import os
import sys


# Get description from Readme file
readme_file = os.path.join(os.path.dirname(__file__), 'README.rst')
long_description = open(readme_file).read()

# Build a list with requirements of the app
REQUIRES = []
try:
    import django
except ImportError:
    # Because of the strange update behavior of "pip --upgrade package_name"
    # set requierment only if django not avallible.
    REQUIRES.append('django')

if sys.version_info < (3, 8):
    REQUIRES.append('python >= 3.8')


setup(
    name='django-onetimelink',
    version=3.2,
    description='A django one-time file streaming application',
    long_description=long_description,
    author='FENG Hao',
    author_email='hiroshifuu@outlook.com',
    url='https://github.com/HiroshiFuu/django-onetimelink',
    download_url='https://pypi.python.org/pypi/django-onetimelink',
    license='BSD',
    packages=find_packages(
        exclude=[
            'example',
        ]
    ),
    include_package_data=True,
    keywords="django one-time file link serve",
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Framework :: Django :: 3.0',
        'Framework :: Django :: 4.0',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3 :: Only',
        'Environment :: Console',
        'Natural Language :: English',
        'Intended Audience :: Developers',
        'Topic :: Internet',
    ],
    install_requires=REQUIRES,
    zip_safe=False,
)
